@@ -453,6 +453,20 @@ vf_sexp_empty_list(void)
   return vf_sexp_alloc(VF_SEXP_TAG_NIL);
 }
 
+SEXP
+vf_sexp_getf(SEXP s, char *key) 
+{
+  SEXP t;
+
+  for (t = s; t->tag == VF_SEXP_TAG_CONS; t = t->t.cons.cdr){
+    if (vf_sexp_stringp(t->t.cons.car) && 
+	strcmp (key, vf_sexp_get_cstring (t->t.cons.car)) == 0){
+      return t->t.cons.cdr;
+    }
+  }
+  return NULL;
+}
+
 
 
 /* 
