@@ -1154,7 +1154,11 @@ draw_char(long code_point, VF_BITMAPLIST buff, int i, int *posxp, int *posyp)
 			    code_point, 1, 1)) == NULL){
       PR3("Cannot get bitmap 0x%lx of font %s\n", 
 	  code_point, font_info[current_font_g[i]].font_name);
-      *posxp = *posxp + ((pixel != 0)?pixel:xpixel)/2;
+      if (chlen_g[i] == 1){
+	*posxp = *posxp + ((pixel != 0)?pixel:xpixel)/2;
+      } else {
+	*posxp = *posxp + ((pixel != 0)?pixel:xpixel);
+      }
     } else {
       if (current_reverse == 1)
 	reverse_bitmap(bm);
