@@ -76,12 +76,14 @@
 #define CHAR_BORDER_FACTOR    1.2
 
 int     Mode = 2;
-char    *FontName;
+char   *FontName;
 double  ArgFontSize = -1;
 double  FontSize = -1;
 double  Dpi_X = 1, Dpi_Y = -1;
 int     OutlineMode = 0;
 int     Verbose = 0;
+int     Mode94x94 = 0;
+int     PageSize = 256;
 double  CharBorderX = CHAR_BORDER_FACTOR;
 double  CharBorderY = CHAR_BORDER_FACTOR;
 
@@ -141,6 +143,9 @@ main(argc, argv)
     } else if (strcmp(argv[0], "-verbose") == 0){
       Verbose = 1;
       continue;
+    } else if (strcmp(argv[0], "-94x94") == 0){
+      Mode94x94 = 1;
+      continue;
     } else if (strcmp(argv[0], "-mode1") == 0){
       Mode = 1;
       continue;
@@ -166,6 +171,8 @@ main(argc, argv)
       FontName = argv[1];
     } else if (strcmp(argv[0], "-v") == 0){
       vflibcap = argv[1];
+    } else if (strcmp(argv[0], "-s") == 0){
+      PageSize = atoi(argv[1]);
     } else if (strcmp(argv[0], "-p") == 0){
       ArgFontSize = atof(argv[1]);
     } else if (strcmp(argv[0], "-m") == 0){
@@ -214,6 +221,10 @@ main(argc, argv)
   PageMax     = 0xffff;
   StartInPage = 0x00;
   EndInPage   = 0xff;
+  if (Mode94x94 != 0){
+    StartInPage = 0x20;
+    EndInPage   = 0x7f;
+  }
   SkipBeginInPage = -1;
   SkipEndInPage   = -1;
   Font_ID = -1;
@@ -496,7 +507,7 @@ int Cmd()
 int CodePoint(c)
      int c;
 {
-  return Page * 0x100 + c;
+  return Page * PageSize + c;
 }
 
 void
